==> qtjambi-dbus-5.15.5-sources.jar: io/qt/dbus/QDBusAbstractAdaptor.java <==
package io.qt.dbus;


/**
 * <p>The base class of D-Bus adaptor classes</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qdbusabstractadaptor.html">QDBusAbstractAdaptor</a></p>
 */
public class QDBusAbstractAdaptor extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDBusAbstractAdaptor.class);
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdbusabstractadaptor.html#QDBusAbstractAdaptor">QDBusAbstractAdaptor::QDBusAbstractAdaptor(QObject*)</a></p>
     */
    protected QDBusAbstractAdaptor(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDBusAbstractAdaptor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdbusabstractadaptor.html#autoRelaySignals">QDBusAbstractAdaptor::autoRelaySignals()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final boolean autoRelaySignals(){
        return autoRelaySignals_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean autoRelaySignals_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdbusabstractadaptor.html#setAutoRelaySignals">QDBusAbstractAdaptor::setAutoRelaySignals(bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void setAutoRelaySignals(boolean enable){
        setAutoRelaySignals_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setAutoRelaySignals_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDBusAbstractAdaptor(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-dbus-5.15.13-sources.jar: io/qt/dbus/QDBusAbstractAdaptor.java <==
package io.qt.dbus;


/**
 * <p>The base class of D-Bus adaptor classes</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdbusabstractadaptor.html">QDBusAbstractAdaptor</a></p>
 */
public class QDBusAbstractAdaptor extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDBusAbstractAdaptor.class);
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdbusabstractadaptor.html#QDBusAbstractAdaptor">QDBusAbstractAdaptor::QDBusAbstractAdaptor(QObject*)</a></p>
     */
    protected QDBusAbstractAdaptor(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDBusAbstractAdaptor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdbusabstractadaptor.html#autoRelaySignals">QDBusAbstractAdaptor::autoRelaySignals()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final boolean autoRelaySignals(){
        return autoRelaySignals_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean autoRelaySignals_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdbusabstractadaptor.html#setAutoRelaySignals">QDBusAbstractAdaptor::setAutoRelaySignals(bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void setAutoRelaySignals(boolean enable){
        setAutoRelaySignals_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setAutoRelaySignals_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDBusAbstractAdaptor(QPrivateConstructor p) { super(p); } 
    
}
